==> gnotepad+_1.0.2.orig.tar.gz: gnotepad+-1.0.2/src/main.h <==
/* vi:set ts=8 sts=0 sw=8:
 * $Id: main.h,v 1.16 1998/10/18 03:56:08 kahn Exp kahn $
 *
 * Copyright (C) 1998 Andy C. Kahn <kahn@zk3.dec.com>
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#ifndef __MAIN_H__
#define __MAIN_H__

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#include <stdio.h>
#include <stdarg.h>
#ifdef WANT_GNOME
#include <config.h>
#include <gnome.h>
#endif
#include "../config.h"
#include "debug.h"


#define APP_NAME	"gnotepad+"
#define APP_VERSION	VERSION
#define APP_DATE	"Oct-18-1998"
#define APP_URL		"http://members.xoom.com/ackahn/gnp"
#define UNTITLED	"Untitled"
#define UNKNOWN		"Unknown"
#define WELCOME_MSG	"Welcome to "
#define NULL_CALLBACK	NULL

#ifdef MAXPATH
#undef MAXPATH
#endif
#define MAXPATH		255

#ifndef ESUCCESS		/* hmm, this is missing on my Linux box */
#define ESUCCESS        0
#endif


typedef unsigned char bool_t;
typedef char byte;
typedef unsigned char ubyte;

typedef enum { FnumCol = 0, FsizeCol, FnameCol } clist_col_t;

#ifndef GTK_HAVE_FEATURES_1_1_0
extern char *g_vsprintf(const char *fmt, va_list *args, va_list *args2);
#endif


#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif	/* __MAIN_H__ */

==> gnotepad+-1.0.8.tar.gz: gnotepad+-1.0.8/src/main.h <==
/* vi:set ts=8 sts=0 sw=8:
 * $Id: main.h,v 1.23 1999/01/21 21:11:07 kahn Exp kahn $
 *
 * Copyright (C) 1998 Andy C. Kahn <kahn@zk3.dec.com>
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#ifndef __MAIN_H__
#define __MAIN_H__

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#include <stdio.h>
#include <stdarg.h>
#include <assert.h>
#ifdef WANT_GNOME
#include <config.h>
#include <gnome.h>
#endif
#include "../config.h"
#include "debug.h"


#ifdef APP_GNP
#define APP_NAME	"gnotepad+"
#define APP_VERSION	VERSION
#define APP_DATE	"Jan-21-1999"
#define APP_URL		"http://members.xoom.com/ackahn/gnp"
#endif

#define UNTITLED	"Untitled"
#define UNKNOWN		"Unknown"
#define WELCOME_MSG	"Welcome to "
#define NULL_CALLBACK	NULL

#ifdef MAXPATH
#undef MAXPATH
#endif
#define MAXPATH		255

#ifndef ESUCCESS		/* hmm, this is missing on my Linux box */
#define ESUCCESS        0
#endif


typedef unsigned char bool_t;
typedef char byte;
typedef unsigned char ubyte;

typedef enum { FnumCol = 0, FsizeCol, FnameCol } clist_col_t;

#ifndef GTK_HAVE_FEATURES_1_1_0
extern char *g_vsprintf(const char *fmt, va_list *args, va_list *args2);
#endif


#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif	/* __MAIN_H__ */
